@@ -100,7 +100,7 @@ class GSPeerConnectionWatcher:
         async def answer(id, description):
 
             if isinstance(description, dict):
-                desc = description
+                desc = type('new_dict', (object,), description)
             else:
                 desc = type('new_dict', (object,), ast.literal_eval(description))
 
